@@ -30,5 +30,5 @@ class SdsTransportException(Exception):
 
   def __repr__(self):
     L = ['%s=%r' % (key, value)
-         for key, value in self.__dict__.iteritems()]
+         for key, value in self.__dict__.items()]
     return '%s(%s)' % (self.__class__.__name__, ', '.join(L))
